/**
 * Copyright Copyright 2008-14 Simon Andrews
 *
 *    This file is part of FocalPoint.
 *
 *    FocalPoint is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    FocalPoint is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with StackMeasure; if not, write to the Free Software
 *    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package uk.ac.bbsrc.babraham.FocalPoint;

import java.awt.BorderLayout;

import javax.swing.ImageIcon;
import javax.swing.JFrame;
import javax.swing.JSplitPane;
import javax.swing.UIManager;

import uk.ac.bbsrc.babraham.FocalPoint.GUI.DirectoryTree;
import uk.ac.bbsrc.babraham.FocalPoint.GUI.IconSizeSlider;
import uk.ac.bbsrc.babraham.FocalPoint.GUI.LocationBar;
import uk.ac.bbsrc.babraham.FocalPoint.GUI.ThumbnailCollection;

public class FocalPointApplication extends JFrame {

	private JSplitPane mainSplitPane;
	public static final String version = "0.6";
	
	public FocalPointApplication () {
		
		setIconImage(new ImageIcon(ClassLoader.getSystemResource("Resources/focal_point_logo.png")).getImage());
		mainSplitPane = new JSplitPane();
		DirectoryTree dirTree = new DirectoryTree();
		mainSplitPane.setLeftComponent(dirTree);
		ThumbnailCollection thumbs = new ThumbnailCollection();
		dirTree.addListener(thumbs);
		mainSplitPane.setRightComponent(thumbs);
		getContentPane().setLayout(new BorderLayout());
		getContentPane().add(mainSplitPane,BorderLayout.CENTER);
		IconSizeSlider slider = new IconSizeSlider();
		slider.addListener(thumbs);
		getContentPane().add(slider,BorderLayout.SOUTH);
		
		LocationBar location = LocationBar.getInstance();
		dirTree.addListener(location);
		getContentPane().add(location,BorderLayout.NORTH);
		
		setTitle("Focal Point");
		setSize(800,600);
		setLocationRelativeTo(null);
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		setVisible(true);
		mainSplitPane.setDividerLocation(0.33);

	}
	
	public static void main(String[] args) {
		
		try {
			UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
		} catch (Exception e) {}
		
		
		new FocalPointApplication();
	}

}
