/**
 * Copyright Copyright 2008-14 Simon Andrews
 *
 *    This file is part of FocalPoint.
 *
 *    FocalPoint is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    FocalPoint is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with StackMeasure; if not, write to the Free Software
 *    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package uk.ac.bbsrc.babraham.FocalPoint.GUI.Thumbnail;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.io.File;
import java.util.Date;

import javax.swing.BorderFactory;
import javax.swing.JLabel;
import javax.swing.JPanel;

public class FileDetailsPanel extends JPanel {

	private File file;
	private String sizeString;
	private GridBagConstraints c;
	private boolean imageDetailsAdded = false;
	private JLabel fileSizeLabel;
	
	public FileDetailsPanel (File file) {
		this.file = file;
		setOpaque(false);
		setBorder(BorderFactory.createEmptyBorder(3,3,3,3));
		setLayout(new GridBagLayout());
		c = new GridBagConstraints();
		c.gridx=0;
		c.gridy=0;
		c.weightx=0.5;
		c.weighty=0.0001;
		c.fill=GridBagConstraints.HORIZONTAL;
		add(new JLabel(file.getName()),c);
		
		c.gridy++;
				
		fileSizeLabel = new JLabel(" ");
		
		add(fileSizeLabel,c);

		setFileSize(file.length());
		
		c.gridy++;
		
		Date d = new Date(file.lastModified());
		
		add (new JLabel(d.toString()),c);
		
	}

	public void setFileSize (long size) {
		String suffix = "B";
		
		if (size > 1024) {
			size /=1024;
			suffix = "kB";
		}

		if (size > 1024) {
			size /=1024;
			suffix = "MB";
		}
		
		if (size > 1024) {
			size /=1024;
			suffix = "GB";
		}
		
		sizeString = size+" "+suffix;
		fileSizeLabel.setText(sizeString);

	}
	
	public void addImageDetails (int x, int y, int slices, int channels) {
		if (imageDetailsAdded) return;
		imageDetailsAdded = true;
		// Add details of the image size
		c.gridy++;
			
		String sliceString = " slices";
		if (slices==1) sliceString = " slice";
		
		String channelString = " channels ";
		if (channels==1) channelString = " channel ";
			
		add(new JLabel(x+" x "+y+"px "+channels+channelString+slices+sliceString),c);
	
		c.gridy++;
		c.weighty=0.9999;
		add(new JLabel(""),c);

	}
	
	public File file () {
		return file;
	}
}
